<?php
namespace SM\Service;

use SM\Factory\BillingComparisonFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Zeedhi\Framework\DataSource\DataSet;

class BillingComparisonService
{
    protected $BillingComparisonFactory;
    protected $Environment;
    protected $newCode;

    public function __construct(BillingComparisonFactory $BillingComparisonFactory, Environment $Environment, NewCode $newCode) {
        $this->BillingComparisonFactory = $BillingComparisonFactory;
        $this->Environment = $Environment;
        $this->newCode = $newCode;
    }

    public function getBillingComparison($parametros) {
        if (isset($parametros["QTPARCELAS"])) {
            // formatando os parametros do contrato para _019_1092_1982
            if ($parametros["NRSEQCONTRATO"] != "-1") {
                $contratos = [];
                foreach ($parametros["NRSEQCONTRATO"] as $value) {
                    $contratos[] = array_shift($value);
                }
                $nrsAux = implode("_", $contratos);
                $nrs = "_" . $nrsAux . "_";
            } else {
                $nrs = null;
            }
        
            if ($parametros["NRPARCNEGOCIO"] != "-1") {
                $parceiro = [];
                foreach ($parametros["NRPARCNEGOCIO"] as $value) {
                    $parceiro[] = array_shift($value);
                }
                $nrsParcAux = implode("_", $parceiro);
                $nrsParc = "_" . $nrsParcAux . "_";
            } else {
                $nrsParc = null;
            }

            if ($parametros["NRTIPOORCAMENTO"] != "-1") {
                $tipoorcamento = [];
                foreach ($parametros["NRTIPOORCAMENTO"] as $value) {
                    $tipoorcamento[] = array_shift($value);
                }
                $nrsTPAux = implode("_", $tipoorcamento);
                $nrsTO = "_" . $nrsTPAux . "_";
            } else {
                $nrsTO = null;
            }

            if ($parametros["IDTPFATURA"] != "-1") {
                $idtpfatura = [];
                foreach ($parametros["IDTPFATURA"] as $value) {
                    $idtpfatura[] = array_shift($value);
                }
                $nrsIDAux = implode("_", $idtpfatura);
                $nrsID = "_" . $nrsIDAux . "_";
            } else {
                $nrsID = null;
            }

            $params = [
                //"DTINICOMPET"         => $parametros["DTINICOMPET"],
                //"DTFINCOMPET"         => $parametros["DTFINCOMPET"],
                "MESCOMPET"           => $parametros["MESCOMPET"],
                "QTPARCELAS"          => $parametros["QTPARCELAS"],
                "NRSEQCONTRATO"       => $nrs,
                "NRPARCNEGOCIO"       => $nrsParc,
                "NRTIPOORCAMENTO"     => $nrsTO,
                "IDTPFATURA"          => $nrsID,
                "VRPERCDIFERENCA_DE"  => isset($parametros["VRPERCDIFERENCA_DE"]) ? $parametros["VRPERCDIFERENCA_DE"] : null,
                "VRPERCDIFERENCA_ATE" => isset($parametros["VRPERCDIFERENCA_ATE"]) ? $parametros["VRPERCDIFERENCA_ATE"] : null,
                "IDTIPO"              => $parametros["IDTIPO"]
            ];

            return $this->BillingComparisonFactory->getBillingComparison($params);
        }
    }

    public function getContractsBillingComparison()
    {
        return $this->BillingComparisonFactory->getContractsBillingComparison();
    }

    public function getBusinessPartnersBilling()
    {
        return $this->BillingComparisonFactory->getBusinessPartnersBilling();
    }

    public function getBillingScopes()
    {
        return $this->BillingComparisonFactory->getBillingScopes();
    }

    public function billingComparisonOfTheParcelTab($parametros)
    {
        $param = [
            "NRFATURACONT" => $parametros["NR"],
        ];

        return $this->BillingComparisonFactory->billingComparisonOfTheParcelTab(
            $param
        );
    }

    public function billingComparisonOfMeasurementItems($parametros)
    {
        $param = [
            "NRMEDICAOFATURA" => $parametros["NR"],
        ];

        return $this->BillingComparisonFactory->billingComparisonOfMeasurementItems(
            $param
        );
    }

    public function billingComparisonOfVariableMeasures($parametros)
    {
        $param = [
            "NRMEDICAOFATURA" => $parametros["NR"],
        ];

        return $this->BillingComparisonFactory->billingComparisonOfVariableMeasures(
            $param
        );
    }
}
